print("import: 'fastapi'")
import fastapi

print("import: 'fastapi.dependencies'")
import fastapi.dependencies

print("import: 'fastapi.middleware'")
import fastapi.middleware

print("import: 'fastapi.openapi'")
import fastapi.openapi

print("import: 'fastapi.security'")
import fastapi.security

